@@ -7,10 +7,10 @@ from gdsfactory.pdk import Pdk
 
 from sky130 import components
 from sky130.config import PATH, module_path
-from sky130.layers import LAYER
+from sky130.layers import LAYER, LAYER_COLORS, LAYER_STACK
 from sky130.tech import cross_sections
 
-__version__ = "0.0.12"
+__version__ = "0.0.14"
 
 cells = get_cells(components)
 PDK = Pdk(
@@ -18,6 +18,8 @@ PDK = Pdk(
     cells=cells,
     cross_sections=cross_sections,
     layers=LAYER.dict(),
+    layer_stack=LAYER_STACK,
+    layer_colors=LAYER_COLORS,
     sparameters_path=PATH.sparameters,
 )
 PDK.register_cells_yaml(dirpath=pathlib.Path(__file__).parent.absolute())
