@@ -1,4 +1,5 @@
 from functools import partial
+
 import gdsfactory as gf
 
 from sky130.config import PATH
@@ -23,7 +24,8 @@ add_ports_m1 = gf.partial(
     layer_label=LAYER.met1label,
     port_type="electrical",
     port_width=0.2,
-    get_name_from_label=True
+    get_name_from_label=True,
+    guess_port_orientation=False,
 )
 add_ports_m2 = gf.partial(
     gf.add_ports.add_ports_from_labels,
@@ -31,7 +33,8 @@ add_ports_m2 = gf.partial(
     layer_label=LAYER.met2label,
     port_type="electrical",
     port_width=0.2,
-    get_name_from_label=True
+    get_name_from_label=True,
+    guess_port_orientation=False,
 )
 add_ports = gf.compose(add_ports_m1, add_ports_m2)
 
@@ -1086,5 +1089,7 @@ if __name__ == "__main__":
     # gf.write_cells.write_cells(gdspath=PATH.gdshs, dirpath="gds")
     # gf.write_cells.write_cells(gdspath=PATH.gdshvl, dirpath="gds")
     # print(gf.write_cells.get_import_gds_script(PATH.gds))
-    c = sky130_fd_sc_hvl__xor2_1()
+    # c = sky130_fd_sc_hvl__xor2_1()
+    # c = sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_2()
+    c = sky130_fd_sc_hd__conb_1()
     c.show()
